@@ -20,6 +20,10 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "display.h"
 #include "compositor_interface.h"
 #include "datadevicemanager_interface.h"
+#include "dpms_interface.h"
+#include "outputconfiguration_interface.h"
+#include "outputmanagement_interface.h"
+#include "outputdevice_interface.h"
 #include "idle_interface.h"
 #include "fakeinput_interface.h"
 #include "logging_p.h"
@@ -29,6 +33,9 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "qtsurfaceextension_interface.h"
 #include "seat_interface.h"
 #include "shadow_interface.h"
+#include "blur_interface.h"
+#include "contrast_interface.h"
+#include "slide_interface.h"
 #include "shell_interface.h"
 #include "subcompositor_interface.h"
 
@@ -61,6 +68,7 @@ public:
     QString socketName = QStringLiteral("wayland-0");
     bool running = false;
     QList<OutputInterface*> outputs;
+    QList<OutputDeviceInterface*> outputdevices;
     QVector<ClientConnection*> clients;
     EGLDisplay eglDisplay = EGL_NO_DISPLAY;
 
@@ -208,6 +216,22 @@ ShellInterface *Display::createShell(QObject *parent)
     return shell;
 }
 
+OutputDeviceInterface *Display::createOutputDevice(QObject *parent)
+{
+    OutputDeviceInterface *output = new OutputDeviceInterface(this, parent);
+    connect(output, &QObject::destroyed, this, [this,output] { d->outputdevices.removeAll(output); });
+    connect(this, &Display::aboutToTerminate, output, [this,output] { removeOutputDevice(output); });
+    d->outputdevices << output;
+    return output;
+}
+
+OutputManagementInterface *Display::createOutputManagement(QObject *parent)
+{
+    OutputManagementInterface *om = new OutputManagementInterface(this, parent);
+    connect(this, &Display::aboutToTerminate, om, [this,om] { delete om; });
+    return om;
+}
+
 SeatInterface *Display::createSeat(QObject *parent)
 {
     SeatInterface *seat = new SeatInterface(this, parent);
@@ -271,6 +295,34 @@ ShadowManagerInterface *Display::createShadowManager(QObject *parent)
     return s;
 }
 
+BlurManagerInterface *Display::createBlurManager(QObject *parent)
+{
+    auto b = new BlurManagerInterface(this, parent);
+    connect(this, &Display::aboutToTerminate, b, [this, b] { delete b; });
+    return b;
+}
+
+ContrastManagerInterface *Display::createContrastManager(QObject *parent)
+{
+    auto b = new ContrastManagerInterface(this, parent);
+    connect(this, &Display::aboutToTerminate, b, [this, b] { delete b; });
+    return b;
+}
+
+SlideManagerInterface *Display::createSlideManager(QObject *parent)
+{
+    auto b = new SlideManagerInterface(this, parent);
+    connect(this, &Display::aboutToTerminate, b, [this, b] { delete b; });
+    return b;
+}
+
+DpmsManagerInterface *Display::createDpmsManager(QObject *parent)
+{
+    auto d = new DpmsManagerInterface(this, parent);
+    connect(this, &Display::aboutToTerminate, d, [this, d] { delete d; });
+    return d;
+}
+
 void Display::createShm()
 {
     Q_ASSERT(d->display);
@@ -283,6 +335,12 @@ void Display::removeOutput(OutputInterface *output)
     delete output;
 }
 
+void Display::removeOutputDevice(OutputDeviceInterface *output)
+{
+    d->outputdevices.removeAll(output);
+    delete output;
+}
+
 quint32 Display::nextSerial()
 {
     return wl_display_next_serial(d->display);
@@ -313,6 +371,11 @@ QList< OutputInterface* > Display::outputs() const
     return d->outputs;
 }
 
+QList< OutputDeviceInterface* > Display::outputDevices() const
+{
+    return d->outputdevices;
+}
+
 ClientConnection *Display::getConnection(wl_client *client)
 {
     Q_ASSERT(client);
